#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall
version:              1.42.3
visibility:           public
id:                   dhall-1.42.3-HZCXaKBJQv38Fu4gZhhmNB
key:                  dhall-1.42.3-HZCXaKBJQv38Fu4gZhhmNB
license:              BSD-3-Clause
copyright:            2017 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             A configuration language guaranteed to terminate
description:
    Dhall is an explicitly typed configuration language that is not Turing
    complete.  Despite being Turing incomplete, Dhall is a real programming
    language with a type-checker and evaluator.

    Use this library to parse, type-check, evaluate, and pretty-print the Dhall
    configuration language.  This package also includes an executable which
    type-checks a Dhall file and reduces the file to a fully evaluated normal
    form.

    Read "Dhall.Tutorial" to learn how to use this library

category:             Compiler
abi:                  8b11c53f8bfecbbe621b4cb90fca0144
exposed:              True
exposed-modules:
    Dhall Dhall.Binary Dhall.Context Dhall.Core Dhall.Crypto
    Dhall.Deriving Dhall.Diff Dhall.DirectoryTree Dhall.Format
    Dhall.Freeze Dhall.Import Dhall.Lint Dhall.Main Dhall.Map
    Dhall.Marshal.Decode Dhall.Marshal.Encode Dhall.Optics
    Dhall.Package Dhall.Parser Dhall.Parser.Expression
    Dhall.Parser.Token Dhall.Pretty Dhall.Repl Dhall.Schemas Dhall.Set
    Dhall.Src Dhall.Substitution Dhall.TH Dhall.Tags Dhall.Tutorial
    Dhall.TypeCheck Dhall.Util Dhall.Version

hidden-modules:
    Dhall.DirectoryTree.Types Dhall.Eval Dhall.Import.Types
    Dhall.Import.Headers Dhall.Marshal.Internal Dhall.Normalize
    Dhall.Parser.Combinators Dhall.Pretty.Internal Dhall.Syntax
    Dhall.Syntax.Binding Dhall.Syntax.Chunks Dhall.Syntax.Const
    Dhall.Syntax.Expr Dhall.Syntax.FunctionBinding Dhall.Syntax.Import
    Dhall.Syntax.Instances.Applicative Dhall.Syntax.Instances.Bifunctor
    Dhall.Syntax.Instances.Data Dhall.Syntax.Instances.Eq
    Dhall.Syntax.Instances.Foldable Dhall.Syntax.Instances.Functor
    Dhall.Syntax.Instances.Lift Dhall.Syntax.Instances.Monad
    Dhall.Syntax.Instances.NFData Dhall.Syntax.Instances.Ord
    Dhall.Syntax.Instances.Pretty Dhall.Syntax.Instances.Show
    Dhall.Syntax.Instances.Traversable Dhall.Syntax.MultiLet
    Dhall.Syntax.Operations Dhall.Syntax.RecordField Dhall.Syntax.Types
    Dhall.Syntax.Var Dhall.URL Paths_dhall Dhall.Import.HTTP
    Dhall.Import.Manager

import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall
hs-libraries:         HSdhall-1.42.3-HZCXaKBJQv38Fu4gZhhmNB
depends:
    Diff-1.0-JevffVw1iEcKOsohkA0eR5
    aeson-2.2.2.0-Kh0pDn2f78S4mLhsXsZzzT
    aeson-pretty-0.8.10-F7wnmrLHen8HYWTw94oY6O
    ansi-terminal-1.1-1lvoyaiIx4qBBztkF1DGdA
    atomic-write-0.2.1.1-LHJXKKPIc6dAKeV8FlN9jE base-4.18.2.1
    base16-bytestring-1.0.2.0-Dowr9jBdlVZBVCdnm9XhEq
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-2w7xRwFPLfwFgOPFogdG9O
    cborg-0.2.10.0-5GEIYD6vramG89eVOzhVvo
    cborg-json-0.2.6.0-Fx8v77YXU2Su52pDCmNV7 containers-0.6.7
    contravariant-1.5.6-DrebhAx4XwC59wq9S42cYg
    cryptohash-sha256-0.11.102.1-1cYcCJcOipn2zkV2xjkmL8
    data-fix-0.3.4-FjtGCy8es9d8KYF9Gq51tG deepseq-1.4.8.1
    directory-1.3.8.5 dotgen-0.4.3-A2UTkkV6Fes7fbL6Rpf3sY
    either-5.0.3-9OubONQRjKcHkZt5QRJXr4 exceptions-0.10.7
    filepath-1.4.300.1 half-0.3.3-3jFvML4RPWnGY0esgbTEgA
    hashable-1.4.7.0-AuDVFqXH7XaG9xiVOVTNBi haskeline-0.8.2.1
    http-client-0.7.19-3CnIhmcn0K76iPGUX0cQMN
    http-client-tls-0.3.6.4-5gkLBXAH8K17sWQOnZNh1
    http-types-0.12.4-KOR1gLg6ER2IlcqJ0qNtQq
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    megaparsec-9.7.0-HRxDu6YnAVL4jvPx7zVygA
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-mtl-0.2.1.0-Ewo8HmKpWhTASatFX3KZGS
    mmorph-1.2.2-I879kMQXeoiA7V1mSxl9UH mtl-2.3.1
    network-uri-2.6.4.2-9CHKirNVw9rJ9Z87o3gbmr
    optparse-applicative-0.18.1.0-7VN2J9FD8HH2Bl1L5dRVhn
    parser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m
    parsers-0.12.12-GnUJ10cL0KT4XkHMC4AdOq
    pretty-simple-4.1.4.0-DtnKZ6XxUFM4axlTQw4xwg
    prettyprinter-1.7.1-E27IB52rJzT5cRmoGOw0uk
    prettyprinter-ansi-terminal-1.1.4-EynbTVBvtsu8QE6iORmNaN
    repline-0.4.3.0-8K1qOV9c7aG2gqDtsaBJvy
    scientific-0.3.8.1-5DbHtB8w5OO3mo7GyLG4Aa
    serialise-0.2.6.1-56CJlFqT7XS6J3YjJojIJe template-haskell-2.20.0.0
    text-2.0.2 text-manipulate-0.3.1.0-BWbliXP2JqOBEg257k4i9V
    text-short-0.1.6.1-K4y0z6pnN0NCPkIECGByqY
    th-lift-instances-0.1.20-EtdiPvxCKz0KlyN5nmUT7E time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unix-compat-0.7.4.1-5qyX2ayBMsxIkyKkm0rJa5
    unordered-containers-0.2.20.1-IS42DvcTPVH3F2RDVwits
    vector-0.13.2.0-1mI63yzxbUH28Wn11C5uSI

haddock-interfaces:   /usr/share/doc/dhall/html/dhall.haddock
haddock-html:         /usr/share/doc/dhall/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

